import { HttpClientModule, HTTP_INTERCEPTORS } from '@angular/common/http';
import { LOCALE_ID, NgModule } from '@angular/core';
import { BrowserModule } from '@angular/platform-browser';
import { BrowserAnimationsModule } from '@angular/platform-browser/animations';
import { ServiceWorkerModule } from '@angular/service-worker';
import { GeometryPolygonConfiguration, MapModule, StructureModule } from '@gouvfr-anct/mediation-numerique';
import { ToastrModule } from 'ngx-toastr';
import metropole from '../assets/geojson/metropole.json';
import { environment } from '../environments/environment';
import { AppRoutingModule } from './app-routing.module';
import { AppComponent } from './app.component';
import { CartoComponent } from './carto/carto.component';
import { CustomBreakPointsProvider } from './config/custom-breakpoint';
import { CustomHttpInterceptor } from './config/http-interceptor';
import { InitialPosition } from './config/map/initial-position';
import { MarkerType } from './config/map/marker-type';
import { ZoomLevel } from './config/map/zoomLevel.enum';
import { ContactComponent } from './contact/contact.component';
import { FooterComponent } from './footer/footer.component';
import { FormViewModule } from './form/form-view/form-view.module';
import { OrientationComponent } from './form/orientation-form/component/orientation-modal/orientation-modal.component';
import { StructureDetailPrintComponent } from './form/orientation-form/component/structure-detail-print/structure-detail-print.component';
import { StructureListPrintComponent } from './form/orientation-form/component/structure-list-print/structure-list-print.component';
import { StructurePrintHeaderComponent } from './form/orientation-form/component/structure-print-header/structure-print-header.component';
import { OrientationFormComponent } from './form/orientation-form/orientation-form.component';
import { AdminGuard } from './guards/admin.guard';
import { AuthGuard } from './guards/auth.guard';
import { DeactivateGuard } from './guards/deactivate.guard';
import { LoginGuard } from './guards/login.guard';
import { RoleGuard } from './guards/role.guard';
import { HeaderComponent } from './header/header.component';
import { LegalNoticeComponent } from './legal-notice/legal-notice.component';
import { LoginComponent } from './login/login.component';
import { NewsletterSubscriptionComponent } from './newsletter-subscription/newsletter-subscription.component';
import { PageComponent } from './page/page.component';
import { ResetEmailComponent } from './reset-email/reset-email.component';
import { ResetPasswordComponent } from './reset-password/reset-password.component';
import { StructureResolver } from './resolvers/structure.resolver';
import { TempUserResolver } from './resolvers/temp-user.resolver';
import { GeojsonService } from './services/geojson.service';
import { RouterListenerService } from './services/routerListener.service';
import { StructureService } from './services/structure.service';
import { UpdateService } from './services/update.service';
import { DataShareConsentComponent } from './shared/components/data-share-consent/data-share-consent.component';
import { SharedModule } from './shared/shared.module';
import { SearchService } from './structure-list/services/search.service';
import { StructureDetailsActionsComponent } from './structure/components/structure-details-actions/structure-details-actions.component';
import { StructureDetailsModalsComponent } from './structure/components/structure-details-modals/structure-details-modals.component';
import { StructureDetailsWrapperComponent } from './structure/components/structure-details-wrapper/structure-details-wrapper.component';
import { TclAccessComponent } from './structure/components/tcl-access/tcl-access.component';
import { StructureExcludeComponent } from './structure/structure-exclude/structure-exclude.component';
import { StructureJoinComponent } from './structure/structure-join/structure-join.component';

@NgModule({
  declarations: [
    AppComponent,
    HeaderComponent,
    FooterComponent,
    CartoComponent,
    LegalNoticeComponent,
    PageComponent,
    ContactComponent,
    ResetEmailComponent,
    ResetPasswordComponent,
    StructureJoinComponent,
    NewsletterSubscriptionComponent,
    OrientationFormComponent,
    StructureDetailPrintComponent,
    StructureListPrintComponent,
    StructurePrintHeaderComponent,
    DataShareConsentComponent,
    OrientationComponent,
    LoginComponent,
    TclAccessComponent,
    StructureDetailsModalsComponent,
    StructureDetailsActionsComponent,
    StructureExcludeComponent,
    StructureDetailsWrapperComponent,
  ],
  imports: [
    BrowserModule,
    HttpClientModule,
    AppRoutingModule,
    SharedModule,
    MapModule.forRoot(
      metropole as GeometryPolygonConfiguration,
      ZoomLevel,
      InitialPosition,
      MarkerType,
      GeojsonService
    ),
    BrowserAnimationsModule,
    ToastrModule.forRoot(),
    StructureModule.forRoot(SearchService, StructureService),
    FormViewModule,
    ServiceWorkerModule.register('ngsw-worker.js', {
      enabled: environment.production,
    }),
  ],
  providers: [
    { provide: LOCALE_ID, useValue: 'fr' },
    { provide: HTTP_INTERCEPTORS, useClass: CustomHttpInterceptor, multi: true },
    CustomBreakPointsProvider,
    AuthGuard,
    AdminGuard,
    RoleGuard,
    LoginGuard,
    DeactivateGuard,
    TempUserResolver,
    StructureResolver,
    RouterListenerService,
    UpdateService,
  ],
  bootstrap: [AppComponent],
})
export class AppModule {}
