import { Component, OnInit } from '@angular/core';
import { UntypedFormGroup } from '@angular/forms';
import { ActivatedRoute, Router } from '@angular/router';
import { Structure } from '@gouvfr-anct/mediation-numerique';
import { structureFormStep } from '../../form/form-view/structure-form/structureFormStep.enum';
import { formUtils, IStructureSummary } from '../../utils/formUtils';

@Component({
  selector: 'app-structure-edition-summary',
  templateUrl: './structure-edition-summary.component.html',
  styleUrls: ['./structure-edition-summary.component.scss'],
})
export class StructureEditionSummaryComponent implements OnInit {
  public structure: Structure;
  public structureForm: UntypedFormGroup;
  constructor(private route: ActivatedRoute, private router: Router) {}
  public summary: IStructureSummary[] = new formUtils().structureSummary;
  public structureFormStep = structureFormStep;

  // There is a non-blocking error in console when open edit mode that occurs only in development mode, please refer https://angular.io/errors/NG0100 for more info

  ngOnInit(): void {
    this.route.data.subscribe((data) => {
      if (data.structure) {
        this.structure = new Structure(data.structure);
        this.structureForm = new formUtils().createStructureForm(this.structure);
      }
    });
  }
  public goBack(): void {
    history.back();
  }
  public goToEdit(step: structureFormStep): void {
    this.router.navigate(['/form/structure', this.structure._id, structureFormStep[step]]);
  }
  public isPageValid(page: IStructureSummary): boolean {
    if (page.inputs) {
      for (let input of page.inputs) {
        if (!this.structureForm.get(input).valid) return false;
      }
    }
    return true;
  }
}
